@@ -1,8 +1,13 @@
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![doc = include_str!("../README.md")]
+
 #[cfg(feature = "unstable")]
 pub mod driver;
 #[cfg(not(feature = "unstable"))]
 mod driver;
 
+pub use driver::{Ws2812Esp32RmtDriver, Ws2812Esp32RmtDriverError};
+
 #[cfg(all(feature = "embedded-graphics-core", feature = "unstable"))]
 pub mod lib_embedded_graphics;
 
